=======
History
=======

0.5.0 (2021-04-08)
------------------

* dependency updates
* endpoint updates for object type and new commit metadata object

0.4.0 (2021-03-08)
------------------

* dependency updates

0.3.0 (2020-12-30)
------------------

* support for python3.9
* correct display of contents in the cli
* better type checking

0.2.1 (2020-10-30)
------------------

* fix install requirements in setup.py

0.2.0 (2020-10-30)
------------------

* git-like cli interface
* more complete coverage of REST endpoints
* better testing

0.1.1 (2020-10-01)
------------------

* First release on PyPI.
